@@ -62,56 +62,12 @@ struct EphyEmbedPrivate
   WebKitWebView *web_view;
   EphyHistory *history;
   GtkWidget *inspector_window;
-  char *loading_uri;
   guint is_setting_zoom : 1;
   GSList *destroy_on_transition_list;
 };
 
 G_DEFINE_TYPE (EphyEmbed, ephy_embed, GTK_TYPE_VBOX)
 
-static void
-uri_changed_cb (WebKitWebView *web_view,
-                GParamSpec *spec,
-                EphyEmbed *embed)
-{
-  char *uri;
-  const char *current_address;
-
-  g_object_get (web_view, "uri", &uri, NULL);
-  current_address = ephy_web_view_get_address (EPHY_WEB_VIEW (web_view));
-
-  /* We need to check if we get URI notifications without going
-     through the usual load process, as this can happen when changing
-     location within a page */
-  if (g_str_equal (uri, current_address) == FALSE)
-    ephy_web_view_set_address (EPHY_WEB_VIEW (web_view), uri);
-
-  g_free (uri);
-}
-
-static void
-title_changed_cb (WebKitWebView *web_view,
-                  GParamSpec *spec,
-                  EphyEmbed *embed)
-{
-  const char *uri;
-  char *title;
-  WebKitWebFrame *frame;
-
-  g_object_get (web_view, "title", &title, NULL);
-
-  ephy_web_view_set_title (EPHY_WEB_VIEW (web_view),
-                           title);
-
-  frame = webkit_web_view_get_main_frame (web_view);
-  uri = webkit_web_frame_get_uri (frame);
-  ephy_history_set_page_title (EPHY_EMBED (embed)->priv->history,
-                               uri,
-                               title);
-  g_free (title);
-
-}
-
 static void
 restore_zoom_level (EphyEmbed *embed,
                     const char *address)
@@ -196,110 +152,25 @@ load_status_changed_cb (WebKitWebView *view,
                         GParamSpec *spec,
                         EphyEmbed *embed)
 {
-  EphyEmbedPrivate *priv = embed->priv;
   WebKitLoadStatus status = webkit_web_view_get_load_status (view);
 
   if (status == WEBKIT_LOAD_COMMITTED) {
     const gchar* uri;
-    EphyWebViewSecurityLevel security_level;
 
     uri = webkit_web_view_get_uri (view);
 
     ephy_embed_destroy_top_widgets (embed);
 
-    if (g_strcmp0 (uri, priv->loading_uri) != 0) {
-      g_free (priv->loading_uri);
-      priv->loading_uri = g_strdup (uri);
-    }
-
-    ephy_web_view_location_changed (EPHY_WEB_VIEW (view),
-                                    uri);
     restore_zoom_level (embed, uri);
+
+    /* FIXME: we are not identifying redirects at the moment */
     ephy_history_add_page (embed->priv->history,
                            uri,
                            FALSE,
                            FALSE);
-
-#ifdef GTLS_SYSTEM_CA_FILE
-    if (uri && g_str_has_prefix (uri, "https")) {
-      WebKitWebFrame *frame;
-      WebKitWebDataSource *source;
-      WebKitNetworkRequest *request;
-      SoupMessage *message;
-
-      frame = webkit_web_view_get_main_frame (view);
-      source = webkit_web_frame_get_data_source (frame);
-      request = webkit_web_data_source_get_request (source);
-      message = webkit_network_request_get_message (request);
-
-      if (message &&
-          (soup_message_get_flags (message) & SOUP_MESSAGE_CERTIFICATE_TRUSTED))
-        security_level = EPHY_WEB_VIEW_STATE_IS_SECURE_HIGH;
-      else
-        security_level = EPHY_WEB_VIEW_STATE_IS_BROKEN;
-    } else
-      security_level = EPHY_WEB_VIEW_STATE_IS_UNKNOWN;
-#else
-    security_level = EPHY_WEB_VIEW_STATE_IS_UNKNOWN;
-#endif
-
-    ephy_web_view_set_security_level (EPHY_WEB_VIEW (view), security_level);
-  } else if (status == WEBKIT_LOAD_PROVISIONAL || status == WEBKIT_LOAD_FINISHED) {
-    EphyWebViewNetState estate = EPHY_WEB_VIEW_STATE_UNKNOWN;
-    char *loading_uri = NULL;
-
-    if (status == WEBKIT_LOAD_PROVISIONAL) {
-      WebKitWebFrame *frame;
-      WebKitWebDataSource *source;
-      WebKitNetworkRequest *request;
-
-      frame = webkit_web_view_get_main_frame (view);
-      source = webkit_web_frame_get_provisional_data_source (frame);
-      request = webkit_web_data_source_get_initial_request (source);
-      loading_uri = g_strdup (webkit_network_request_get_uri (request));
-
-      /* We also store the URI we are currently loading here, because
-       * we will want to use it in WEBKIT_LOAD_FINISHED, because if a
-       * load fails we may never get to committed */
-      priv->loading_uri = g_strdup (loading_uri);
-
-      estate = (EphyWebViewNetState) (estate |
-                                      EPHY_WEB_VIEW_STATE_START |
-                                      EPHY_WEB_VIEW_STATE_NEGOTIATING |
-                                      EPHY_WEB_VIEW_STATE_IS_REQUEST |
-                                      EPHY_WEB_VIEW_STATE_IS_NETWORK);
-      
-      g_signal_emit_by_name (EPHY_WEB_VIEW (view), "new-document-now", loading_uri);
-    } else if (status == WEBKIT_LOAD_FINISHED) {
-      loading_uri = priv->loading_uri;
-
-      /* Will be freed below */
-      priv->loading_uri = NULL;
-
-      estate = (EphyWebViewNetState) (estate |
-                                      EPHY_WEB_VIEW_STATE_STOP |
-                                      EPHY_WEB_VIEW_STATE_IS_DOCUMENT |
-                                      EPHY_WEB_VIEW_STATE_IS_NETWORK);
-    }
-
-    ephy_web_view_update_from_net_state (EPHY_WEB_VIEW (view),
-                                         loading_uri,
-                                         (EphyWebViewNetState)estate);
-
-    g_free (loading_uri);
-
   }
 }
 
-static void
-hovering_over_link_cb (WebKitWebView *web_view,
-                       char *title,
-                       char *location,
-                       EphyEmbed *embed)
-{
-  ephy_web_view_set_link_message (EPHY_WEB_VIEW (web_view), location);
-}
-
 static void
 zoom_changed_cb (WebKitWebView *web_view,
                  GParamSpec *pspec,
@@ -334,6 +205,13 @@ zoom_changed_cb (WebKitWebView *web_view,
   g_free (address);
 }
 
+static void
+ephy_embed_history_cleared_cb (EphyHistory *history,
+                               EphyEmbed *embed)
+{
+  ephy_web_view_clear_history (EPHY_WEB_VIEW (embed->priv->web_view));
+}
+
 static void
 ephy_embed_grab_focus (GtkWidget *widget)
 {
@@ -351,8 +229,6 @@ ephy_embed_finalize (GObject *object)
   EphyEmbed *embed = EPHY_EMBED (object);
   GSList *list;
 
-  g_free (embed->priv->loading_uri);
-
   list = embed->priv->destroy_on_transition_list;
   for (; list; list = list->next) {
     GtkWidget *widget = GTK_WIDGET (list->data);
@@ -360,6 +236,10 @@ ephy_embed_finalize (GObject *object)
   }
   g_slist_free (embed->priv->destroy_on_transition_list);
 
+  g_signal_handlers_disconnect_by_func (embed->priv->history,
+                                        ephy_embed_history_cleared_cb,
+                                        embed);
+
   G_OBJECT_CLASS (ephy_embed_parent_class)->finalize (object);
 }
 
@@ -485,6 +365,7 @@ static const char*
 parse_extension (const char *filename)
 {
   const char *compression;
+  const char *last_separator;
 
   compression = file_is_compressed (filename);
 
@@ -511,7 +392,8 @@ parse_extension (const char *filename)
   }
 
   /* no compression, just look for the last dot in the filename */
-  return g_strrstr (filename, ".");
+  last_separator = strrchr (filename, G_DIR_SEPARATOR);
+  return strrchr ((last_separator) ? last_separator : filename, '.');
 }
 
 static gboolean
@@ -670,7 +552,7 @@ confirm_action_from_mime (WebKitWebView *web_view,
                           DownloadAction action)
 {
   GtkWidget *parent_window;
-  GtkWidget *dialog, *button, *image;
+  GtkWidget *dialog;
   const char *action_label;
   char *mime_description;
   EphyMimePermission mime_permission;
@@ -679,6 +561,9 @@ confirm_action_from_mime (WebKitWebView *web_view,
   int default_response;
   WebKitNetworkResponse *response;
   SoupMessage *message;
+  GtkMessageType mtype;
+  char *title;
+  char *secondary;
 
   parent_window = gtk_widget_get_toplevel (GTK_WIDGET(web_view));
   if (!gtk_widget_is_toplevel (parent_window))
@@ -721,57 +606,48 @@ confirm_action_from_mime (WebKitWebView *web_view,
   suggested_filename = webkit_download_get_suggested_filename (download);
 
   if (mime_permission != EPHY_MIME_PERMISSION_SAFE && helper_app) {
-    dialog = gtk_message_dialog_new (GTK_WINDOW (parent_window),
-                                     GTK_DIALOG_DESTROY_WITH_PARENT,
-                                     GTK_MESSAGE_WARNING, GTK_BUTTONS_NONE,
-                                     _("Download this potentially unsafe file?"));
+    title = _("Download this potentially unsafe file?");
+    mtype = GTK_MESSAGE_WARNING;
+    /* translators: First %s is the file type description, second %s is the
+     * file name */
+    secondary = g_strdup_printf (_("File Type: “%s”.\n\nIt is unsafe to open "
+                                   "“%s” as it could potentially damage your "
+                                   "documents or invade your privacy. "
+                                   "You can download it instead."),
+                                 mime_description, suggested_filename);
 
-    gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-                                              /* translators: First %s is the file type description,
-                                                 Second %s is the file name */
-                                              _("File Type: “%s”.\n\nIt is unsafe to open “%s” as "
-                                                "it could potentially damage your documents or "
-                                                "invade your privacy. You can download it instead."),
-                                              mime_description, suggested_filename);
     action_label = STOCK_DOWNLOAD;
   } else if (action == DOWNLOAD_ACTION_OPEN && helper_app) {
-    dialog = gtk_message_dialog_new (GTK_WINDOW (parent_window),
-                                     GTK_DIALOG_DESTROY_WITH_PARENT,
-                                     GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE,
-                                     _("Open this file?"));
-
-    gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-                                              /* translators: First %s is the file type description,
-                                                 Second %s is the file name,
-                                                 Third %s is the application used to open the file */
-                                              _("File Type: “%s”.\n\nYou can open “%s” using “%s” or save it."),
-                                              mime_description, suggested_filename,
-                                              g_app_info_get_name (helper_app));
+    title = _("Open this file?");
+    mtype = GTK_MESSAGE_QUESTION;
+    /* translators: First %s is the file type description, second %s is the
+     * file name, third %s is the application used to open the file */
+    secondary = g_strdup_printf (_("File Type: “%s”.\n\nYou can open “%s” "
+                                   "using “%s” or save it."),
+                                 mime_description, suggested_filename,
+                                 g_app_info_get_name (helper_app));
   } else  {
-    dialog = gtk_message_dialog_new (GTK_WINDOW (parent_window),
-                                     GTK_DIALOG_DESTROY_WITH_PARENT,
-                                     GTK_MESSAGE_QUESTION, GTK_BUTTONS_NONE,
-                                     _("Download this file?"));
-
-    gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
-                                              /* translators: First %s is the file type description,
-                                                 Second %s is the file name */
-                                              _("File Type: “%s”.\n\nYou have no application able to open “%s”. "
-                                                "You can download it instead."),
-                                              mime_description, suggested_filename);
+    title = _("Download this file?");
+    mtype = GTK_MESSAGE_QUESTION;
+    /* translators: First %s is the file type description, second %s is the
+     * file name */
+    secondary = g_strdup_printf (_("File Type: “%s”.\n\nYou have no "
+                                   "application able to open “%s”. "
+                                   "You can download it instead."),
+                                 mime_description, suggested_filename);
   }
 
+  dialog = gtk_message_dialog_new (GTK_WINDOW (parent_window),
+                                   GTK_DIALOG_DESTROY_WITH_PARENT,
+                                   mtype, GTK_BUTTONS_NONE,
+                                   title);
+  gtk_message_dialog_format_secondary_text (GTK_MESSAGE_DIALOG (dialog),
+                                            secondary, NULL);
+
   g_free (mime_description);
 
-  button = gtk_button_new_with_mnemonic (_("_Save As..."));
-  image = gtk_image_new_from_stock (GTK_STOCK_SAVE_AS, GTK_ICON_SIZE_BUTTON);
-  gtk_button_set_image (GTK_BUTTON (button), image);
-  gtk_widget_set_can_default (button, TRUE);
-  /* don't show the image! see bug #307818 */
-  gtk_widget_show (button);
-  gtk_dialog_add_action_widget (GTK_DIALOG (dialog),
-                                button, DOWNLOAD_ACTION_DOWNLOAD);
-
+  gtk_dialog_add_button (GTK_DIALOG (dialog),
+                         GTK_STOCK_SAVE_AS, DOWNLOAD_ACTION_DOWNLOAD);
   gtk_dialog_add_button (GTK_DIALOG (dialog),
                          GTK_STOCK_CANCEL, GTK_RESPONSE_CANCEL);
   gtk_dialog_add_button (GTK_DIALOG (dialog),
@@ -919,11 +795,8 @@ ephy_embed_constructed (GObject *object)
   g_object_connect (web_view,
                     "signal::notify::load-status", G_CALLBACK (load_status_changed_cb), embed,
                     "signal::resource-request-starting", G_CALLBACK (resource_request_starting_cb), embed,
-                    "signal::hovering-over-link", G_CALLBACK (hovering_over_link_cb), embed,
                     "signal::download-requested", G_CALLBACK (download_requested_cb), embed,
                     "signal::notify::zoom-level", G_CALLBACK (zoom_changed_cb), embed,
-                    "signal::notify::title", G_CALLBACK (title_changed_cb), embed,
-                    "signal::notify::uri", G_CALLBACK (uri_changed_cb), embed,
                     NULL);
 
   embed->priv->inspector_window = gtk_window_new (GTK_WINDOW_TOPLEVEL);
@@ -956,6 +829,10 @@ ephy_embed_constructed (GObject *object)
   ephy_embed_prefs_add_embed (embed);
 
   embed->priv->history = EPHY_HISTORY (ephy_embed_shell_get_global_history (ephy_embed_shell_get_default ()));
+
+  g_signal_connect (embed->priv->history,
+                    "cleared", G_CALLBACK (ephy_embed_history_cleared_cb),
+                    embed);
 }
 
 static void
